@@ -1,5 +1,6 @@
 import sys
 import click
+import os
 try:
     from .funcs import *
     from . import const
@@ -57,6 +58,27 @@ def rm(**kwargs):
     removeScript(name)
 
 
+@main.command()
+def install(**kwargs):
+    os.system('pip install -r requirements.txt')
+
+
+@main.command()
+def freeze(**kwargs):
+    os.system('pip3 freeze > requirements.txt')
+
+@main.command()
+def build(**kwargs):
+    runScript('build')
+
+@main.command()
+def start(**kwargs):
+    runScript('start')
+
+@main.command()
+def start(**kwargs):
+    runScript('deploy')
+
 if __name__ == '__main__':
     args = sys.argv
     if "--help" in args or len(args) == 1:
